@@ -19,7 +19,7 @@ use Unicode::UTF8 qw(encode_utf8);
 Readonly::Scalar our $URI_BASE => 'https://mix-n-match.toolforge.org/';
 Readonly::Scalar our $URI_CATALOG_DETAIL => $URI_BASE.'api.php?query=catalog_details&catalog=%s';
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -32,7 +32,17 @@ sub new {
 	return $self;
 }
 
-sub command_diff {
+sub _catalog_json_file_to_obj {
+	my $json_file = shift;
+
+	my $json = slurp($json_file);
+	my $struct_hr = decode_json($json);
+	my $obj = Toolforge::MixNMatch::Struct::Catalog::struct2obj($struct_hr->{'data'});
+
+	return $obj;
+}
+
+sub _command_diff {
 	my ($json_file1, $json_file2, $print_options) = @_;
 
 	if (! defined $json_file1 || ! -r $json_file1) {
@@ -42,22 +52,10 @@ sub command_diff {
 		return (1, "Doesn't exist JSON file #2 for diff.");
 	}
 
-	my $opts_hr;
-	if (defined $print_options) {
-		$opts_hr = {};
-		foreach my $print_option (split m/,/, $print_options) {
-			$opts_hr->{$print_option} = 1;
-		}
-	}
+	my $opts_hr = _process_print_options($print_options);
 
-	my $json1 = slurp($json_file1);
-	my $json2 = slurp($json_file2);
-
-	my $cat1_hr = decode_json($json1);
-	my $cat2_hr = decode_json($json2);
-
-	my $obj1 = Toolforge::MixNMatch::Struct::Catalog::struct2obj($cat1_hr->{'data'});
-	my $obj2 = Toolforge::MixNMatch::Struct::Catalog::struct2obj($cat2_hr->{'data'});
+	my $obj1 = _catalog_json_file_to_obj($json_file1);
+	my $obj2 = _catalog_json_file_to_obj($json_file2);
 
 	my $diff = Toolforge::MixNMatch::Diff::diff($obj1, $obj2);
 
@@ -67,7 +65,7 @@ sub command_diff {
 	return (0, undef);
 }
 
-sub command_download {
+sub _command_download {
 	my ($catalog_id, $output_file) = @_;
 
 	if (! defined $catalog_id || $catalog_id !~ m/^\d+$/ms) {
@@ -77,7 +75,7 @@ sub command_download {
 		$output_file = $catalog_id.'.json';
 	}
 
-	my $json = download_catalog_detail($catalog_id);
+	my $json = _download_catalog_detail($catalog_id);
 	barf($output_file, $json);
 
 	print "Catalog with '$catalog_id' ID was saved to '$output_file'.\n";
@@ -85,25 +83,19 @@ sub command_download {
 	return (0, undef);
 }
 
-sub command_print {
+sub _command_print {
 	my ($json_file_or_catalog_id, $print_options) = @_;
 
 	my $json;
 	if (-r $json_file_or_catalog_id) {
 		$json = slurp($json_file_or_catalog_id);
 	} elsif ($json_file_or_catalog_id =~ m/^\d+$/ms) {
-		$json = download_catalog_detail($json_file_or_catalog_id);
+		$json = _download_catalog_detail($json_file_or_catalog_id);
 	} else {
 		return (1, "Doesn't exist JSON file or catalog ID for print.");
 	}
 
-	my $opts_hr;
-	if (defined $print_options) {
-		$opts_hr = {};
-		foreach my $print_option (split m/,/, $print_options) {
-			$opts_hr->{$print_option} = 1;
-		}
-	}
+	my $opts_hr = _process_print_options($print_options);
 
 	my $struct_hr = decode_json($json);
 	my $obj = Toolforge::MixNMatch::Struct::Catalog::struct2obj($struct_hr->{'data'});
@@ -113,7 +105,7 @@ sub command_print {
 	return (0, undef);
 }
 
-sub download_catalog_detail {
+sub _download_catalog_detail {
 	my $catalog_id = shift;
 
 	my $uri = sprintf $URI_CATALOG_DETAIL, $catalog_id;
@@ -125,6 +117,22 @@ sub download_catalog_detail {
 	return $json;
 }
 
+sub _process_print_options {
+	my $print_options = shift;
+
+	if (! defined $print_options) {
+		return;
+	}
+
+
+	my $opts_hr = {};
+	foreach my $print_option (split m/,/, $print_options) {
+		$opts_hr->{$print_option} = 1;
+	}
+
+	return $opts_hr;
+}
+
 # Run script.
 sub run {
 	my $self = shift;
@@ -157,11 +165,11 @@ sub run {
 
 	my ($return, $error);
 	if ($command eq 'diff') {
-		($return, $error) = command_diff(@command_args);
+		($return, $error) = _command_diff(@command_args);
 	} elsif ($command eq 'download') {
-		($return, $error) = command_download(@command_args);
+		($return, $error) = _command_download(@command_args);
 	} elsif ($command eq 'print') {
-		($return, $error) = command_print(@command_args);
+		($return, $error) = _command_print(@command_args);
 	} else {
 		print STDERR "Command '$command' doesn't supported.\n";
 		return 1;
@@ -224,9 +232,21 @@ App::Toolforge::MixNMatch - Perl class for mix-n-match application.
  exit App::Toolforge::MixNMatch->new->run;
 
  # Output:
- # Usage: ./examples/ex1.pl [-h] [--version]
+ # Usage: ./examples/ex1.pl [-h] [--version] [command] [command_args ..]
  #         -h              Print help.
  #         --version       Print version.
+ #         command         Command (diff, download, print).
+ #
+ #         command 'diff' arguments:
+ #                 json_file1 - JSON file #1
+ #                 json_file2 - JSON file #2
+ #                 [print_options] - Print options (type, count, year_months, users)
+ #         command 'download' arguments:
+ #                 catalog_id - Catalog ID
+ #                 [output_file] - Output file (default is catalog_id.json)
+ #         command 'print' arguments:
+ #                 json_file or catalog_id - Catalog ID or JSON file
+ #                 [print_options] - Print options (type, count, year_months, users)
 
 =head1 DEPENDENCIES
 
@@ -250,6 +270,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
